<?php
/*
Plugin Name: Elegant Tabs for WooCommerce
Plugin URI: http://www.infiwebs.com/plugins/elegant-tabs-woo
Description: Convert boaring WooCommerce tabs into beautifully crafted elegant tabs.
Version: 1.0.1
Author: InfiWebs
Author URI: http://www.infiwebs.com
*/
class ElegantWooTabs{
	var $iw_tabs;
    function __construct() {
        // Register and enqueue CSS and JS on frontend
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
		
		// Enqueue CSS and JS on backend
        add_action( 'admin_print_scripts', array( $this, 'printCssAndJs' ) );
				
		add_filter( 'woocommerce_product_tabs', array($this, 'infi_elegant_tabs' ), 100);
		add_filter( 'woocommerce_product_tab_panels', array($this, 'infi_elegant_tabs2' ), 100);
		add_action( 'woocommerce_product_write_panel_tabs', array( $this, 'create_admin_tab' ) );
		add_action( 'woocommerce_product_write_panels', array( $this, 'woo_add_custom_general_fields' ) );
		add_action( 'woocommerce_process_product_meta',  array( $this, 'woo_tabs_meta_update' ) );
		add_action( 'wp_ajax_update_elegant_tab_options','update_elegant_tab_options' );
		add_action( 'wp_ajax_nopriv_update_elegant_tab_options', 'update_elegant_tab_options' );
    }
	function infi_elegant_tabs($tabs ) {
		global $post;
		$tab_style = $color_act_txt = $color_act_bg = $el_class = $style = $color_content_bg = $color_content_txt = $tab_animation = '';
		$elegant_tabs_meta = get_post_meta($post->ID, 'elegant_woo_tabs_meta', true);
		$elegant_tabs_defaults = get_option('elegant_woo_tabs_defaults');
		if(!isset($elegant_tabs_meta['color_tab_txt'])){
			$elegant_tabs_meta = $elegant_tabs_defaults;
		}
		
		$tab_style 			= isset($elegant_tabs_meta['tab_style']) ? $elegant_tabs_meta['tab_style'] : 'bars';
		$tab_animation 		= isset($elegant_tabs_meta['tab_animation']) ? $elegant_tabs_meta['tab_animation'] : 'fadeIn';
		$color_tab_txt 		= isset($elegant_tabs_meta['color_tab_txt']) ? $elegant_tabs_meta['color_tab_txt'] : '#FFFFFF';
		$color_tab_bg 		 = isset($elegant_tabs_meta['color_tab_bg']) ? $elegant_tabs_meta['color_tab_bg'] : '#2a90da';
		$color_act_txt 		= isset($elegant_tabs_meta['color_act_txt']) ? $elegant_tabs_meta['color_act_txt'] : '#2a90da';
		$color_act_bg 		 = isset($elegant_tabs_meta['color_act_bg']) ? $elegant_tabs_meta['color_act_bg'] : '#f2f2f2';
		$color_content_bg 	 = isset($elegant_tabs_meta['color_content_bg']) ? $elegant_tabs_meta['color_content_bg'] : '#f2f2f2';
		$color_content_txt 	= isset($elegant_tabs_meta['color_content_txt']) ? $elegant_tabs_meta['color_content_txt'] : '#383838';
		

		$rand = uniqid();
		if($tab_style !== "line"){
			$style .= 'background:'.$color_tab_bg.';';
		}
		$style .= 'color:'.$color_tab_txt.';';
		?>
			<section>
				<div class="et-tabs et-tabs-style-<?php echo $tab_style; ?> tab-class-<?php echo $rand; ?>" data-tab_style='<?php echo $tab_style;?>' data-active-bg='<?php echo $color_act_bg;?>' data-active-text='<?php echo $color_act_txt;?>'>
					<nav>
						<ul>
						<?php foreach ( $tabs as $key => $tab ) : ?>
                            <li class="<?php echo $key ?>_tab" style=" <?php echo $style; ?>">
                                <a href="#tab-<?php echo $key ?>" style="color:<?php echo $color_tab_txt;?>;">
                                <?php echo apply_filters( 'woocommerce_product_' . $key . '_tab_title', $tab['title'], $key ) ?>
                                </a>
                            </li>
                    	<?php endforeach; ?>
						</ul>
					</nav>
					<div class="et-content-wrap" style="background:<?php echo $color_content_bg.';color:'.$color_content_txt;?>;">
					<?php foreach ( $tabs as $key => $tab ) : ?>
                    <section class="panel entry-content" id="tab-<?php echo $key ?>" data-animation="<?php echo $tab_animation;?>">
                        <?php call_user_func( $tab['callback'], $key, $tab ) ?>
                    </section>
        
                <?php endforeach; ?>
					</div><!-- /et-content-wrap -->
				</div><!-- /et-tabs -->
			 </section>
		<?php
	}
	function woo_add_custom_general_fields() {
		global $woocommerce, $post;
		?>
		<div id="infi_elegant_tabs" class="panel woocommerce_options_panel">
			<p class="toolbar" style=" margin-top: 0; ">
            	<strong><?php _e("Choose different style and colors for the tabs being displayed on this product page.","woocommerce"); ?></strong>
			</p>
			<div class="options_group">
				<?php
					$elegant_tabs_meta = get_post_meta($post->ID, 'elegant_woo_tabs_meta', true);
					$elegant_tabs_defaults = get_option('elegant_woo_tabs_defaults');
					if(!isset($elegant_tabs_meta['color_tab_txt'])){
						$elegant_tabs_meta = $elegant_tabs_defaults;
					}
										
					$tab_styles = array(
						"Bar Style"				 => "bars",
						"Icon Box Style"			=> "iconbox",
						"Underline Style"		   => "underline",
						"Top Line Style"			=> "topline",
						"Central Line Style"		=> "iconfall",
						"Line Style"				=> "line",
						"Line Box Style"			=> "linebox",
						"Flip Style"				=> "flip",
						"Trapezoid Style"		   => "tzoid",
						"Fillup Style"			  => "fillup",
					);
					
					$tab_animation = array(
						__("No Animation","infiwebs") => "",
						__("Swing","infiwebs") => "swing",
						__("Pulse","infiwebs") => "pulse",
						__("Flash","infiwebs") => "flash",
						__("Fade In","infiwebs") => "fadeIn",
						__("Fade In Up","infiwebs") => "fadeInUp",
						__("Fade In Down","infiwebs") => "fadeInDown",
						__("Fade In Left","infiwebs") => "fadeInLeft",
						__("Fade In Right","infiwebs") => "fadeInRight",
						__("Fade In Up Long","infiwebs") => "fadeInUpBig",
						__("Fade In Down Long","infiwebs") => "fadeInDownBig",
						__("Fade In Left Long","infiwebs") => "fadeInLeftBig",
						__("Fade In Right Long","infiwebs") => "fadeInRightBig",
						__("Slide In Down","infiwebs") => "slideInDown",
						__("Slide In Up","infiwebs") => "slideInUp",
						__("Slide In Left","infiwebs") => "slideInLeft",
						__("Bounce In","infiwebs") => "bounceIn",
						__("Bounce In Up","infiwebs") => "bounceInUp",
						__("Bounce In Down","infiwebs") => "bounceInDown",
						__("Bounce In Left","infiwebs") => "bounceInLeft",
						__("Bounce In Right","infiwebs") => "bounceInRight",
						__("Rotate In","infiwebs") => "rotateIn",
						__("Light Speed In","infiwebs") => "lightSpeedIn",
						__("Roll In","infiwebs") => "rollIn",
					);
				?>
                <p class="form-field">
                <label for="tab_style"><?php _e('Select Tab Style:','infiwebs');?></label>
                <select name="tab_style" id="tab_style">
                	<?php
						foreach($tab_styles as $label => $value){
							$sel = $value == $elegant_tabs_meta['tab_style'] ? 'selected' : '';
							echo '<option value="'.$value.'" '.$sel.'>'.$label.'</option>';
						}
                    ?>
                </select>
                <img class="help_tip" data-tip="Select any tab style you would like to use. For visual demo of the tabs, please visit the plugins demo page." src="<?php echo plugins_url('/assets/images/help.png',WC_PLUGIN_FILE); ?>" height="16" width="16" />
                </p>
                <p class="form-field">
                <label for="tab_animation"><?php _e('Select Tab Animation:','infiwebs');?></label>
                <select name="tab_animation" id="tab_animation">
                	<?php
						foreach($tab_animation as $label => $value){
							$sel = $value == $elegant_tabs_meta['tab_animation'] ? 'selected' : '';
							echo '<option value="'.$value.'" '.$sel.'>'.$label.'</option>';
						}
                    ?>
                </select>
                <img class="help_tip" data-tip="Select animation type for the tab content area. Animation will be applied when the tab is switched to another." src="<?php echo plugins_url('/assets/images/help.png',WC_PLUGIN_FILE); ?>" height="16" width="16" />
                </p>
			</div>
			<div class="options_group">
            	<p class="form-field">
                	<label for="color_tab_txt"><?php _e('Tab Text Color:','infiwebs');?></label>
                	<input type="text" id="color_tab_txt" name="color_tab_txt" value="<?php echo $elegant_tabs_meta['color_tab_txt']; ?>" class="iw-color-field" />
                </p>
                <p class="form-field">
                	<label for="color_tab_bg"><?php _e('Tab Background / Border Color:','infiwebs');?></label>
                	<input type="text" id="color_tab_bg" name="color_tab_bg" value="<?php echo $elegant_tabs_meta['color_tab_bg']; ?>" class="iw-color-field" />
                </p>
                <p class="form-field">
                	<label for="color_act_txt"><?php _e('Active Tab Text Color:','infiwebs');?></label>
                	<input type="text" id="color_act_txt" name="color_act_txt" value="<?php echo $elegant_tabs_meta['color_act_txt']; ?>" class="iw-color-field" />
                </p>
                <p class="form-field">
                	<label for="color_act_bg"><?php _e('Active Tab Background / Border Color:','infiwebs');?></label>
                	<input type="text" id="color_act_bg" name="color_act_bg" value="<?php echo $elegant_tabs_meta['color_act_bg']; ?>" class="iw-color-field" />
                </p>
                <p class="form-field">
                	<label for="color_content_bg"><?php _e('Tab Content Background Color:','infiwebs');?></label>
                	<input type="text" id="color_content_bg" name="color_content_bg" value="<?php echo $elegant_tabs_meta['color_content_bg']; ?>" class="iw-color-field" />
                </p>
                 <p class="form-field">
                	<label for="color_content_txt"><?php _e('Tab Content Text Color:','infiwebs');?></label>
                	<input type="text" id="color_content_txt" name="color_content_txt" value="<?php echo $elegant_tabs_meta['color_content_txt']; ?>" class="iw-color-field" />
                </p>
            </div>
		</div>		  
	 <?php
	}
	/*
    Update tabs meta values
    */
	function woo_tabs_meta_update()
	{
		global $post;
		$elegant_woo_tabs = array();
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
		{
			return $post->ID;
		}
		if(isset($_POST["tab_style"]))
		{
			$elegant_woo_tabs['tab_style'] = $_POST["tab_style"];
		}
		if(isset($_POST["tab_animation"])){
			$elegant_woo_tabs['tab_animation'] = $_POST["tab_animation"];
		}
		if(isset($_POST["color_tab_txt"])){
			$elegant_woo_tabs['color_tab_txt'] = $_POST["color_tab_txt"];
		}
		if(isset($_POST["color_tab_bg"])){
			$elegant_woo_tabs['color_tab_bg'] = $_POST["color_tab_bg"];
		}
		if(isset($_POST["color_act_txt"])){
			$elegant_woo_tabs['color_act_txt'] = $_POST["color_act_txt"];
		}
		if(isset($_POST["color_act_bg"])){
			$elegant_woo_tabs['color_act_bg'] = $_POST["color_act_bg"];
		}
		if(isset($_POST["color_content_bg"])){
			$elegant_woo_tabs['color_content_bg'] = $_POST["color_content_bg"];
		}
		if(isset($_POST["color_content_txt"])){
			$elegant_woo_tabs['color_content_txt'] = $_POST["color_content_txt"];
		}
		
		update_post_meta($post->ID, "elegant_woo_tabs_meta", $elegant_woo_tabs);
	}
 
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function loadCssAndJs() {
      
		// enqueue CSS files on front end.
		wp_register_style( 'iw_tab_style', plugins_url('css/tabstyles.css', __FILE__) );
		wp_register_style( 'iw_tab_aminate', plugins_url('css/animate.min.css', __FILE__) );
		wp_register_style( 'iw_tabs', plugins_url('css/tabs.css', __FILE__) );
		
		wp_enqueue_style( 'iw_tab_style' );
		wp_enqueue_style( 'iw_tab_aminate' );
		wp_enqueue_style( 'iw_tabs' );
		
		// enqueue javascript files on front end.
		wp_enqueue_script( 'iw_tabs', plugins_url('js/eTabs.js', __FILE__), array('jquery'),'',true );
    }
	
	 /*
    Load plugin css and javascript files which you may need on backend of your site
    */
    public function printCssAndJs() {
		wp_enqueue_script( 'iw_meta_script', plugins_url('js/meta-tabs.js', __FILE__), array('jquery','wp-color-picker'),'',true );
     }
	 /* this creates the tab in the products section in the admin panel */
	function create_admin_tab()
	{
		echo "<li class='infi_elegant_tab'><a href='#infi_elegant_tabs'>".__('Elegant Tabs', 'woocommerce')."</a></li>";
	}
}
// Finally initialize code
new ElegantWooTabs;
require_once('admin/tabs-admin.php');
if(!function_exists('update_elegant_tab_options')){
	function update_elegant_tab_options(){
		$elegant_woo_tabs = array();
		if(isset($_POST["tab_style"]))
		{
			$elegant_woo_tabs['tab_style'] = $_POST["tab_style"];
		}
		if(isset($_POST["tab_animation"])){
			$elegant_woo_tabs['tab_animation'] = $_POST["tab_animation"];
		}
		if(isset($_POST["color_tab_txt"])){
			$elegant_woo_tabs['color_tab_txt'] = $_POST["color_tab_txt"];
		}
		if(isset($_POST["color_tab_bg"])){
			$elegant_woo_tabs['color_tab_bg'] = $_POST["color_tab_bg"];
		}
		if(isset($_POST["color_act_txt"])){
			$elegant_woo_tabs['color_act_txt'] = $_POST["color_act_txt"];
		}
		if(isset($_POST["color_act_bg"])){
			$elegant_woo_tabs['color_act_bg'] = $_POST["color_act_bg"];
		}
		if(isset($_POST["color_content_bg"])){
			$elegant_woo_tabs['color_content_bg'] = $_POST["color_content_bg"];
		}
		if(isset($_POST["color_content_txt"])){
			$elegant_woo_tabs['color_content_txt'] = $_POST["color_content_txt"];
		}
		
		$result = update_option("elegant_woo_tabs_defaults", $elegant_woo_tabs);
		echo $result;
		die();
	}
}